<?php
/**
 * Copyright (C) 2024  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use Civi\Api4\BbbEventLog;
use CRM_Bigbluebutton_ExtensionUtil as E;

class CRM_Bigbluebutton_Form_EventLog extends CRM_Core_Form {

  public function preProcess() {
    CRM_Utils_System::setTitle(ts('Big Blue Button Webhook Event Log'));

    $eventApi = \Civi\Api4\BbbEventLog::get();

    $formValues = $this->getSubmitValues();
    if (isset($formValues['event']) && !empty($formValues['event'])) {
      $eventApi->addWhere('event', 'LIKE', '%' . CRM_Utils_Type::escape($formValues['event'], 'String') . '%');
    }
    if (isset($formValues['meeting_id']) && !empty($formValues['meeting_id'])) {
      $meetingId = CRM_Utils_Type::escape($formValues['meeting_id'], 'String');
      $eventApi->addClause('OR', ['meeting_id', '=', $meetingId], ['internal_meeting_id', '=', $meetingId]);
    }

    $countApi = clone $eventApi;
    $countApiResult = $countApi->execute();
    $total = $countApiResult->count();

    $params['total'] = $total;
    $params['currentPage'] = $this->get(CRM_Utils_Pager::PAGE_ID);
    $params['rowCount'] = CRM_Utils_Pager::ROWCOUNT;
    $params['status'] = ts('Log entries %%StatusMessage%%');
    $this->_pager = new CRM_Utils_Pager($params);
    $this->assign_by_ref('pager', $this->_pager);
    [$offset, $limit] = $this->_pager->getOffsetAndRowCount();

    $events = $eventApi
      ->addOrderBy('timestamp', 'DESC')
      ->setOffset($offset)
      ->setLimit($limit)
      ->execute()
      ->getArrayCopy();

    $this->assign_by_ref('events', $events);

    parent::preProcess();
  }


  public function buildQuickForm() {
    parent::buildQuickForm();

    $this->add('text', 'event', E::ts('Event contains'), array('class' => 'huge'));
    $this->add('text', 'meeting_id', E::ts('Meeting ID or Internal Meeting ID'), array('class' => 'huge'));
    $this->addButtons(array(
      array(
        'type' => 'refresh',
        'name' => E::ts('Zoeken'),
        'isDefault' => TRUE,
      ),
    ));
  }

  public function postProcess() {

  }


}