<?php
/**
 * Copyright (C) 2024  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use CRM_Bigbluebutton_ExtensionUtil as E;

class CRM_Bigbluebutton_Page_ManageWebhooks extends CRM_Core_Page {
  public function run() {
    CRM_Utils_System::setTitle(E::ts('Manage Webhooks'));

    $action = CRM_Utils_Request::retrieve('action', 'String');
    $id = CRM_Utils_Request::retrieve('id', 'Positive');
    if ($action & CRM_Core_Action::DELETE && $id) {
      try {
        $api = new \Civi\Api4\Action\BigBlueButton\HooksDestroy('BigBlueButton', 'destory');
        $api->setValues(['hookID' => $id]);
        $api->execute();
        CRM_Core_Session::setStatus(E::ts('Webhook removed'), E::ts('Big Blue Button'), 'success');
      }
      catch (\Civi\API\Exception\UnauthorizedException|API_Exception $e) {
        CRM_Core_Session::setStatus(E::ts('Could not remove webhook'), E::ts('Big Blue Button'), 'error');
      }
    }

    $api = new \Civi\Api4\Action\BigBlueButton\HooksList('BigBlueButton', 'HooksList');
    try {
      $webhooks = $api->execute()->first();
    }
    catch (\Civi\API\Exception\UnauthorizedException|API_Exception $e) {
      $webhooks = [];
    }
    if (isset($webhooks['hooks']['hook']) && (!is_array($webhooks['hooks']['hook']) || isset($webhooks['hooks']['hook']['hookID']))) {
      $webhooks['hooks']['hook'] = array($webhooks['hooks']['hook']);
    }
    if (isset($webhooks['hooks']['hook']) && is_array($webhooks['hooks']['hook'])) {
      $webhooks = $webhooks['hooks']['hook'];
    } else {
      $webhooks = [];
    }
    if (!is_array($webhooks)) {
      $webhooks = [];
    }
    $this->assign('webhooks', $webhooks);
    parent::run();
  }
}