<?php
/**
 * Copyright (C) 2024  Jaap Jansma (jaap.jansma@civicoop.org)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Civi\Api4\Action\BigBlueButton;

use Civi\Api4\Generic\Result;
use Civi\BigBlueButton\Call;

/**
 * Return info about a meeting in Big Blue Button
 *
 * This call will return all of a meeting's information, including the list of
 * attendees as well as start and end times.
 * https://docs.bigbluebutton.org/development/api/#get-post-getmeetinginfo
 *
 * @package Civi\Api4\Action\BigBlueButton
 */

class HooksList extends AbstractBBBAPi {

  /**
   * Returns the API call name. E.g. create or join.
   *
   * @return string
   */
  protected function getApiCallName(): string {
    return 'hooks/list';
  }

  /**
   * Return the HTTP Method.
   *
   * @return string
   */
  protected function getHttpMethod(): string {
    return 'GET';
  }

}
